#! /usr/bin/env python

import unittest, os, re
import shutil, tempfile

import base, util

import test_cvs
svn_importer=test_cvs.cvs_importer+['--scm=svn']


class SVN_Repository:
	def __init__(self):
		self.tmpdir = tempfile.mktemp()
		self.reposdir = os.path.join(self.tmpdir, 'repos')
		self.repospath = 'file://'+self.reposdir ####todo: handle dos paths
		os.mkdir(self.tmpdir, 0700)
		os.mkdir(self.reposdir, 0700)
		util.safesystem('svnadmin','create',self.reposdir)
		self.importer = svn_importer + ['-d', self.repospath]

	def __del__(self):
		if hasattr(self,'tmpdir') and os.path.exists(self.tmpdir):
			print 'SVN_Repository: removing',self.tmpdir
			shutil.rmtree(self.tmpdir)
	
	def checkout(self,name,ver=None):
		self.codir = os.path.join(self.tmpdir, 'co')
		if os.path.exists(self.codir):
			shutil.rmtree(self.codir)
		os.mkdir(self.codir, 0700)
		if ver:
			rpath = self.repospath + '/' + name + '-' + re.sub('[^-_0-9a-zA-Z]', '_', ver)
		else:
			rpath = self.repospath + '/' + name
		util.safesystem('svn','co', rpath, self.codir)
	
	def get_ignore_list(self, path):
		olddir = os.getcwd()
		os.chdir(self.codir)
		try:
			return util.getoutput('svn','propget','svn:ignore',path).rstrip().splitlines()
		finally:
			os.chdir(olddir)
		
	def get_log(self, path):
		olddir = os.getcwd()
		os.chdir(self.codir)
		try:
			return util.getoutput('svn','log',path)
		finally:
			os.chdir(olddir)

	def is_binary(self, path):
		olddir = os.getcwd()
		os.chdir(self.codir)
		try:
			mimetype = util.getoutput('svn','propget','svn:mime-type',path).strip()
			if not mimetype or mimetype.startswith("text/"):
				return 0
			return 1
		finally:
			os.chdir(olddir)
		

class SVNTestCase(base.CommonTests, base.TestCase):
	def setUp(self):
		base.CommonTests.setUp(self)
		self.repos = SVN_Repository()
	def tearDown(self):
		base.CommonTests.tearDown(self)
		del self.repos
	
	def test_empty_dir(self):
		self.do_addver("1.0", add=["dir1/"])
		self.do_addver("1.1", add=["dir1/file1"])
		self.do_addver("1.2", rm=["dir1/file1"])
		self.do_import()
		self.do_verify_all()


if __name__ == '__main__':
	unittest.main()
